.. image:: https://img.shields.io/pypi/v/django-otp-agents?color=blue
   :target: https://pypi.org/project/django-otp-agents/
   :alt: PyPI
.. image:: https://img.shields.io/readthedocs/django-otp-agents
   :target: https://django-otp-agents.readthedocs.io/
   :alt: Documentation
.. image:: https://img.shields.io/badge/github-django--otp--agents-green
   :target: https://github.com/django-otp/django-otp-agents
   :alt: Source

This uses `django-agent-trust`_ to add OTP-based machine authorization to
django-otp.

See `django-otp`_ for more information on the OTP framework.


.. _django-agent-trust: http://pypi.org/project/django-agent-trust
.. _django-otp: http://pypi.org/project/django-otp
